/*!
* CrushFTP Common methods
*
* http://crushFTP.com/
*
* Copyright 2012, CrushFTP
*
* Author: Vipul Limbachiya
*
* http://vipullimbachiya.com
*/

// Various methods that adds form functionalities and prototypes to existing methods

//jQuery function, clears form fields
$.fn.clearForm = function () {
	return this.each(function () {
		var type = this.type,
			tag = this.tagName.toLowerCase();
		if (tag == 'form' || tag == 'div') return $(':input', this).clearForm();
		if (type == 'text' || type == 'password' || tag == 'textarea') this.value = '';
		else if (type == 'checkbox' || type == 'radio') {
			this.checked = false;
			if(window.userManager)
				userManager.UI.checkUnchekInput($(this), false);
			else if(window.adminPanel)
				adminPanel.UI.checkUnchekInput($(this), false);
		}
		else if (tag == 'select') this.selectedIndex = -1;
	});
};

//Create buttons UI
function buildButtons(context){
	$(".button", context).each(function(){
		var icon = $(this).attr("icon");
		if(icon)
		{
			$(this).button(
			{
				icons: {
					primary: icon
				}
			});
		}
		else
		{
			$(this).button();
		}
	});
}

//Swap 2 array items
Array.prototype.swapItems=function(a, b){
    var temp = this[a];
	this[a] = this[b];
	this[b] = temp;
	return this;
}

// Check if specified array has item
Array.prototype.has = function (value) {
	var i;
	for (var i = 0, loopCnt = this.length; i < loopCnt; i++) {
		if (this[i] === value) {
			return true;
		}
	}
	return false;
};

// Few buggy browsers does not have indexOf for an array, add it if not available
if(!Array.prototype.indexOf)
{
	Array.prototype.indexOf = function (value) {
		var i;
		for (var i = 0, loopCnt = this.length; i < loopCnt; i++) {
			if (this[i] === value) {
				return i;
			}
		}
		return -1;
	};
}

if (!('filter' in Array.prototype)) {
    Array.prototype.filter= function(filter, that /*opt*/) {
        var other= [], v;
        for (var i=0, n= this.length; i<n; i++)
            if (i in this && filter.call(that, v= this[i], i, this))
                other.push(v);
        return other;
    };
}

//Array diff
Array.prototype.diff = function(a) {
    return this.filter(function(i) {return !(a.indexOf(i) > -1);});
};

// Array Remove - By John Resig (MIT Licensed)
Array.prototype.remove = function(from, to) {
  var rest = this.slice((to || from) + 1 || this.length);
  this.length = from < 0 ? this.length + from : from;
  return this.push.apply(this, rest);
};

//Max val in array
Array.prototype.max = function() {
	var max = this[0];
	var len = this.length;
	for (var i = 1; i < len; i++) if (this[i] > max) max = this[i];
	return max;
}

// Zero-Fill
String.prototype.zf = function(l) { return '0'.string(l - this.length) + this; }
Number.prototype.zf = function(l) { return this.toString().zf(l); }

// VB-like string
String.prototype.string = function(l) { var s = '', i = 0; while (i++ < l) { s += this; } return s; }

// Capitalize first character
String.prototype.capitalize = function() {
    return this.charAt(0).toUpperCase() + this.slice(1);
}

// Date format prototype : http://www.codeproject.com/KB/scripting/dateformat.aspx
Date.prototype.format = function(f)
{
    if (!this.valueOf())
        return ' ';

    var d = this;

    return f.replace(/(yyyy|mmmm|mmm|mm|dddd|ddd|dd|hh|nn|ss|a\/p)/gi,
        function($1)
        {
            switch ($1.toLowerCase())
            {
            case 'yyyy': return d.getFullYear();
            case 'mmmm': return gsMonthNames[d.getMonth()];
            case 'mmm':  return gsMonthNames[d.getMonth()].substr(0, 3);
            case 'mm':   return (d.getMonth() + 1).zf(2);
            case 'dddd': return gsDayNames[d.getDay()];
            case 'ddd':  return gsDayNames[d.getDay()].substr(0, 3);
            case 'dd':   return d.getDate().zf(2);
            case 'hh':   return ((h = d.getHours() % 12) ? h : 12).zf(2);
            case 'nn':   return d.getMinutes().zf(2);
            case 'ss':   return d.getSeconds().zf(2);
            case 'a/p':  return d.getHours() < 12 ? 'AM' : 'PM';
            }
        }
    );
}

if(!String.prototype.shuffle)
{
	String.prototype.shuffle = function () {
		var a = this.split(""),
			n = a.length;

		for(var i = n - 1; i > 0; i--) {
			var j = Math.floor(Math.random() * (i + 1));
			var tmp = a[i];
			a[i] = a[j];
			a[j] = tmp;
		}
		return a.join("");
	}
}

function getTextFromXML(doc)
{
	var string = "";
	//for IE
    if (window.ActiveXObject) {
       string = doc.xml;
    }
    // code for Mozilla, Firefox, Opera, etc.
    else {
       string = (new XMLSerializer()).serializeToString(doc);
    }
	return string;
}

// Adding in-case sensitive filter
jQuery.expr[':'].Contains = function(a,i,m){
    return (a.textContent || a.innerText || "").toUpperCase().indexOf(m[3].toUpperCase())>=0;
};

//A Delay method based on timeout
var delay = (function () {
	var timer = 0;
	return function (callback, ms) {
		clearTimeout(timer);
		timer = setTimeout(callback, ms);
	};
})();

(function() {
  function DateDiff(date1, date2) {
    this.days = null;
    this.hours = null;
    this.minutes = null;
    this.seconds = null;
    this.date1 = date1;
    this.date2 = date2;
    this.init();
  }
  
  DateDiff.prototype.init = function() {
    var data = new DateMeasure(this.date1 - this.date2);
    this.days = data.days;
    this.hours = data.hours;
    this.minutes = data.minutes;
    this.seconds = data.seconds;
  };

  function DateMeasure(ms) {
    var d, h, m, s;
    s = Math.floor(ms / 1000);
    m = Math.floor(s / 60);
    s = s % 60;
    h = Math.floor(m / 60);
    m = m % 60;
    d = Math.floor(h / 24);
    h = h % 24;
    
    this.days = d;
    this.hours = h;
    this.minutes = m;
    this.seconds = s;
  };

  Date.diff = function(date1, date2) {
    return new DateDiff(date1, date2);
  };

  Date.prototype.diff = function(date2) {
    return new DateDiff(this, date2);
  };
})();